==> paraview-2.4.2.tbz: lib/paraview-2.4/ParaViewConfig.cmake <==
SET(PARAVIEW_VERSION_MAJOR "2")
SET(PARAVIEW_VERSION_MINOR "4")
SET(PARAVIEW_VERSION_PATCH "2")

SET(PARAVIEW_BUILD_SHARED_LIBS "ON")
SET(PARAVIEW_USE_FILE "/usr/local/lib/paraview-2.4/ParaViewUse.cmake")
SET(PARAVIEW_VTK_DIR "/usr/local/lib/paraview-2.4-build/VTK")

SET(VTKCS_SOURCE_DIR "/usr/local/lib/paraview-2.4/Utilities/VTKClientServer")

SET(PARAVIEW_CMAKE_EXTENSIONS
  "/usr/local/lib/paraview-2.4/VTK/CMake")
SET(PARAVIEW_CMAKE_CLIENT_SERVER_EXTENSION
  "/usr/local/lib/paraview-2.4/Utilities/VTKClientServer/CMake/vtkWrapClientServer.cmake")
SET(VTK_WRAP_ClientServer_EXE "")
SET(PARAVIEW_INCLUDE_DIRS "/usr/local/lib/paraview-2.4/Utilities/VTKClientServer;/usr/local/lib/paraview-2.4/Utilities/hdf5;/usr/local/lib/paraview-2.4/Servers/Filters;/usr/local/lib/paraview-2.4/Servers/ServerManager;/usr/local/lib/paraview-2.4/Servers/Common;/usr/local/lib/paraview-2.4/GUI/Widgets;/usr/local/lib/paraview-2.4/GUI/Client;/usr/local/lib/paraview-2.4-build;/usr/local/lib/paraview-2.4-build/Utilities/VTKClientServer;/usr/local/lib/paraview-2.4-build/Utilities/hdf5;/usr/local/lib/paraview-2.4-build/Servers/Filters;/usr/local/lib/paraview-2.4-build/Servers/ServerManager;/usr/local/lib/paraview-2.4-build/Servers/Common;/usr/local/lib/paraview-2.4-build/GUI/Widgets;/usr/local/lib/paraview-2.4-build/GUI/Client;/usr/local/lib/paraview-2.4/Utilities/Xdmf/vtk;/usr/local/lib/paraview-2.4-build/Utilities/Xdmf/vtk")
SET(PARAVIEW_LIBRARY_DIRS "/usr/local/lib/paraview-2.4-build/bin")

SET(PARAVIEW_GUI_INCLUDE_DIRS "/usr/local/lib/paraview-2.4/VTK/Utilities;/usr/local/lib/paraview-2.4-build/VTK/Utilities;/usr/local/lib/paraview-2.4/VTK;/usr/local/lib/paraview-2.4-build/VTK")
SET(PARAVIEW_KWSYS_INCLUDE_DIRS "/usr/local/lib/paraview-2.4-build/VTK/Utilities")

SET(PARAVIEW_GUI_CLIENT_EXECUTABLE "/usr/local/lib/paraview-2.4-build/bin/paraview")
SET(PARAVIEW_BATCH_EXECUTABLE "/usr/local/lib/paraview-2.4-build/bin/pvbatch")
SET(PARAVIEW_PROCESS_XML_EXECUTABLE "/usr/local/lib/paraview-2.4-build/bin/kwProcessXML")
SET(PARAVIEW_SERVER_MANAGER_RESOURCES_DIRECTORY "/usr/local/lib/paraview-2.4/Servers/ServerManager/Resources")

# The ParaView library dependencies.
IF(NOT PARAVIEW_NO_LIBRARY_DEPENDS)
  INCLUDE("/usr/local/lib/paraview-2.4-build/ParaViewLibraryDepends.cmake")
ENDIF(NOT PARAVIEW_NO_LIBRARY_DEPENDS)

==> paraview-2.4.4_1.tbz: lib/paraview-2.4/ParaViewConfig.cmake <==
SET(PARAVIEW_VERSION_MAJOR "2")
SET(PARAVIEW_VERSION_MINOR "4")
SET(PARAVIEW_VERSION_PATCH "4")

SET(PARAVIEW_BUILD_SHARED_LIBS "ON")
SET(PARAVIEW_USE_FILE "/usr/local/lib/paraview-2.4/ParaViewUse.cmake")
SET(PARAVIEW_VTK_DIR "/usr/local/lib/paraview-2.4-build/VTK")

SET(VTKCS_SOURCE_DIR "/usr/local/lib/paraview-2.4/Utilities/VTKClientServer")

SET(PARAVIEW_CMAKE_EXTENSIONS
  "/usr/local/lib/paraview-2.4/VTK/CMake")
SET(PARAVIEW_CMAKE_CLIENT_SERVER_EXTENSION
  "/usr/local/lib/paraview-2.4/Utilities/VTKClientServer/CMake/vtkWrapClientServer.cmake")
SET(VTK_WRAP_ClientServer_EXE "")
SET(PARAVIEW_INCLUDE_DIRS "/usr/local/lib/paraview-2.4/Utilities/VTKClientServer;/usr/local/lib/paraview-2.4/Utilities/hdf5;/usr/local/lib/paraview-2.4/Servers/Filters;/usr/local/lib/paraview-2.4/Servers/ServerManager;/usr/local/lib/paraview-2.4/Servers/Common;/usr/local/lib/paraview-2.4/GUI/Widgets;/usr/local/lib/paraview-2.4/GUI/Client;/usr/local/lib/paraview-2.4-build;/usr/local/lib/paraview-2.4-build/Utilities/VTKClientServer;/usr/local/lib/paraview-2.4-build/Utilities/hdf5;/usr/local/lib/paraview-2.4-build/Servers/Filters;/usr/local/lib/paraview-2.4-build/Servers/ServerManager;/usr/local/lib/paraview-2.4-build/Servers/Common;/usr/local/lib/paraview-2.4-build/GUI/Widgets;/usr/local/lib/paraview-2.4-build/GUI/Client;/usr/local/lib/paraview-2.4/Utilities/Xdmf/vtk;/usr/local/lib/paraview-2.4-build/Utilities/Xdmf/vtk")
SET(PARAVIEW_LIBRARY_DIRS "/usr/local/lib/paraview-2.4-build/bin")

SET(PARAVIEW_GUI_INCLUDE_DIRS "")
SET(PARAVIEW_KWSYS_INCLUDE_DIRS "/usr/local/lib/paraview-2.4-build/VTK/Utilities")

SET(PARAVIEW_GUI_CLIENT_EXECUTABLE "/usr/local/lib/paraview-2.4-build/bin/paraview")
SET(PARAVIEW_BATCH_EXECUTABLE "/usr/local/lib/paraview-2.4-build/bin/pvbatch")
SET(PARAVIEW_PROCESS_XML_EXECUTABLE "/usr/local/lib/paraview-2.4-build/bin/kwProcessXML")
SET(PARAVIEW_SERVER_MANAGER_RESOURCES_DIRECTORY "/usr/local/lib/paraview-2.4/Servers/ServerManager/Resources")

# The ParaView library dependencies.
IF(NOT PARAVIEW_NO_LIBRARY_DEPENDS)
  INCLUDE("/usr/local/lib/paraview-2.4-build/ParaViewLibraryDepends.cmake")
ENDIF(NOT PARAVIEW_NO_LIBRARY_DEPENDS)
